@@ -14,8 +14,6 @@ from rook.factory import Factory
 from ..augs import actions, conditions, extractors, locations
 from ..augs.aug import Aug
 
-from .processor_extensions.operations.celery_rdb import CeleryRdb, CeleryRdbGetPort
-
 
 from rook.rookout_json import json
 from rook import config
@@ -33,7 +31,7 @@ class AugFactory(Factory):
         super(AugFactory, self).__init__()
 
         self._output = output
-        self._processor_factory = ProcessorFactory([CeleryRdb, CeleryRdbGetPort], [])
+        self._processor_factory = ProcessorFactory([], [])
 
         self._load_dynamic_classes()
 
