@@ -28,7 +28,6 @@ class Information(object):
                 logger.debug("Failed to collect %s information: %s", name, exc)
 
                 setattr(self, name, "")
-                pass
 
         self.debug = debug
 
@@ -37,6 +36,7 @@ class Information(object):
 
 class SCMInformation(Information):
     def __init__(self):
+        super(SCMInformation, self).__init__()
         self._collectors = {
             'commit': self._get_commit,
             'origin': self._get_origin
@@ -74,6 +74,7 @@ class SCMInformation(Information):
 
 class NetworkInformation(Information):
     def __init__(self):
+        super(NetworkInformation, self).__init__()
         self._collectors = {
             'ip_addr': self._get_ip_addr,
             'network': platform.node()
@@ -88,6 +89,7 @@ class NetworkInformation(Information):
 
 class SystemInformation(Information):
     def __init__(self):
+        super(SystemInformation, self).__init__()
         self._collectors = {
             'hostname': socket.gethostname,
             'os': platform.system,
@@ -114,6 +116,7 @@ class SystemInformation(Information):
 
 class VersionInformation(Information):
     def __init__(self):
+        super(VersionInformation, self).__init__()
         self._collectors = {
             'version': VersionConfiguration.VERSION,
             'commit': VersionConfiguration.COMMIT
@@ -122,6 +125,7 @@ class VersionInformation(Information):
 
 class PlatformInformation(Information):
     def __init__(self):
+        super(PlatformInformation, self).__init__()
         self._collectors = {
             'platform': 'python',
             'version': sys.version,
@@ -131,6 +135,7 @@ class PlatformInformation(Information):
 
 class AgentInformation(Information):
     def __init__(self):
+        super(AgentInformation, self).__init__()
         self._collectors = {
             'version': lambda: VersionInformation().collect(),
             'network': lambda: NetworkInformation().collect(),
