@@ -13,10 +13,10 @@ import six
 import websocket
 
 from rook.exceptions import RookCommunicationException, RookInvalidToken, RookDependencyConflict, RookMessageSizeExceeded
-import rook.com_ws.socketpair_compat  # do not remove - adds socket.socketpair on Windows
+import rook.com_ws.socketpair_compat  # do not remove - adds socket.socketpair on Windows lgtm[py/unused-import]
 
 try:
-    from websocket import WebSocketBadStatusException
+    from websocket import WebSocketBadStatusException # This is used to make sure we have the right version lgtm[py/unused-import]
 except ImportError:
     raise RookDependencyConflict('websocket')
 
@@ -26,7 +26,6 @@ if not websocket._ssl_compat.HAVE_SSL:
     try:
         import backports.ssl
         import backports.ssl_match_hostname
-        import OpenSSL
         websocket._http.ssl = backports.ssl
         websocket._http.HAVE_SSL = True
         websocket._http.HAVE_CONTEXT_CHECK_HOSTNAME = True
@@ -124,13 +123,14 @@ class AgentCom(object):
 
     def add(self, message):
         if self._queue.qsize() >= AgentComConfiguration.MAX_QUEUED_MESSAGES:
-            return
+            return None
 
         packaged_message = wrap_in_envelope(message)
         if len(packaged_message) > AgentComConfiguration.MAX_MESSAGE_LENGTH:
             return RookMessageSizeExceeded(len(packaged_message), AgentComConfiguration.MAX_MESSAGE_LENGTH)
 
         self._queue.put(packaged_message)
+        return None
 
     def on(self, message_name, callback):
         self._register_callback(message_name, MessageCallback(callback, True))
@@ -472,4 +472,4 @@ class AgentCom(object):
         return self._connection.send_binary(message)
 
     def _register_callback(self, message_name, callback):
-        self._callbacks.setdefault(message_name, []).append(callback)
\ No newline at end of file
+        self._callbacks.setdefault(message_name, []).append(callback)
