@@ -2,10 +2,12 @@ import logging
 import time
 
 from rook import config
+from rook.user_warnings import UserWarnings
 from rook.com_ws.token_bucket import TokenBucket
 from rook.protobuf.messages_pb2 import RuleStatusMessage, AugReportMessage, LogMessage
 from rook.protobuf.variant_pb2 import Error
 from rook.processor.namespace_serializer import NamespaceSerializer
+from rook.processor.error import Error as RookError
 from rook.processor.namespaces.container_namespace import ContainerNamespace
 from rook.logger import logger
 
@@ -68,7 +70,9 @@ class Output(object):
             if arguments and arguments.size(''):
                 NamespaceSerializer().dump(arguments, msg.arguments)
 
-            self._agent_com.add(msg)
+            error = self._agent_com.add(msg)
+            if error:
+                UserWarnings.send_warning(RookError(error))
         self._user_message_bucket.do_if_available(send_msg)
 
     LOG_LEVELS = {
