@@ -9,7 +9,6 @@ import six
 from rook.config import ImportServiceConfig
 from rook.serverless import on_lambda
 
-
 _rook = None
 _debug = False
 _throw_errors = False
@@ -35,6 +34,7 @@ def start(token=None,
           git_origin=None,
           proxy=None,
           fork=None,
+          enable_monitor=None,
           **kwargs):
     global _rook, _debug, _throw_errors, _original_args, _fork
 
@@ -59,9 +59,7 @@ def start(token=None,
     else:
         _debug = os.environ.get('ROOKOUT_DEBUG') in _TRUE_VALUES
 
-    if isinstance(log_to_stderr, bool):
-        log_to_stderr = log_to_stderr
-    else:
+    if not isinstance(log_to_stderr, bool):
         log_to_stderr = os.environ.get('ROOKOUT_LOG_TO_STDERR') in _TRUE_VALUES
 
     if isinstance(throw_errors, bool):
@@ -100,6 +98,8 @@ def start(token=None,
 
     _fork = fork or os.environ.get('ROOKOUT_ENABLE_FORK', False) in _TRUE_VALUES
 
+    _enable_monitor = enable_monitor or os.environ.get('ROOKOUT_ENABLE_MONITOR', True) in _TRUE_VALUES
+
     try:
         from rook.exceptions.tool_exceptions import RookMissingToken, RookInvalidToken, RookVersionNotSupported, \
             RookCommunicationException, RookInvalidOptions, RookLoadError, RookOldServers
@@ -159,7 +159,7 @@ def start(token=None,
                                           proxy=proxy, throw_errors=throw_errors, log_level=log_level,
                                           log_to_stderr=log_to_stderr, log_file=log_file, git_commit=git_commit,
                                           git_origin=git_origin, tags=tags, labels=labels, async_start=async_start,
-                                          use_import_hook=use_import_hook, fork=_fork)
+                                          use_import_hook=use_import_hook, fork=_fork, enable_monitor=_enable_monitor)
 
             if (host == "staging.cloud.agent.rookout.com") or (host == "cloud.agent.rookout.com"):
                 raise RookOldServers()
@@ -171,7 +171,7 @@ def start(token=None,
             import rook.singleton
             _rook = rook.singleton.singleton_obj
 
-            return _rook.connect(token, host, port, proxy, tags, labels, async_start, _fork, _debug)
+            _rook.connect(token, host, port, proxy, tags, labels, async_start, _fork, _debug, _enable_monitor)
         except (RookMissingToken, RookInvalidToken, RookVersionNotSupported, RookOldServers) as e:
             if not _throw_errors:
                 six.print_("[Rookout] Failed to start Rookout:", e, file=sys.stderr)
@@ -265,5 +265,5 @@ def _print_user_configuration(**kwargs):
             if value:
                 config_string = config_string + ("%s: %s, " % (key, value))
         six.print_("RookOptions: " + config_string)
-    except:
-        pass
+    except Exception:
+        six.print_("Error in printing user configuration")
