@@ -31,24 +31,24 @@ class Error(object):
                 error.message = NamespaceSerializer.normalize_string(self.message)
             else:
                 error.message = ''
-        except Exception:
+        except Exception: # We are already deep in error handling code - just ignore
             pass
 
         try:
             error.type = NamespaceSerializer.normalize_string(self.type)
-        except Exception:
+        except Exception: # We are already deep in error handling code - just ignore
             pass
 
         try:
             serializer = NamespaceSerializer()
             serializer.dump(PythonObjectNamespace(self.parameters), error.parameters, False)
-        except Exception:
+        except Exception: # We are already deep in error handling code - just ignore
             pass
 
         try:
             serializer = NamespaceSerializer()
             serializer.dump(PythonObjectNamespace(self.exc), error.exc, False)
-        except Exception:
+        except Exception: # We are already deep in error handling code - just ignore
             pass
 
         try:
@@ -58,7 +58,7 @@ class Error(object):
                 serializer.dump(PythonObjectNamespace(traceback_string,
                                                       PythonObjectNamespace.ObjectDumpConfig.tailor_limits(traceback_string)),
                                 error.traceback, False)
-        except Exception:
+        except Exception: # We are already deep in error handling code - just ignore
             pass
 
     def dumps(self):
