@@ -51,37 +51,37 @@ class NamespaceSerializer(object):
     def dump(self, namespace, variant, log_errors=True):
         try:
             if isinstance(namespace, ContainerNamespace):
-                return self._dump_container_namespace(namespace, variant, log_errors)
+                self._dump_container_namespace(namespace, variant, log_errors)
             elif isinstance(namespace, PythonObjectNamespace):
-                return self._dump_object_namespace(namespace, variant, log_errors)
+                self._dump_object_namespace(namespace, variant, log_errors)
             elif isinstance(namespace, StringNamespace):
-                return self._dump_string_namespace(namespace, variant, log_errors)
+                self._dump_string_namespace(namespace, variant, log_errors)
             elif isinstance(namespace, DumpedPrimitiveNamespace):
-                return self._dump_primitive_namespace(namespace, variant, log_errors)
+                self._dump_primitive_namespace(namespace, variant, log_errors)
             elif isinstance(namespace, UserObjectNamespace):
-                return self._dump_user_object_namespace(namespace, variant, log_errors)
+                self._dump_user_object_namespace(namespace, variant, log_errors)
             elif isinstance(namespace, ListNamespace):
-                return self._dump_list_namespace(namespace, variant, log_errors)
+                self._dump_list_namespace(namespace, variant, log_errors)
             elif isinstance(namespace, DictNamespace):
-                return self._dump_dictionary_namespace(namespace, variant, log_errors)
+                self._dump_dictionary_namespace(namespace, variant, log_errors)
             elif isinstance(namespace, ErrorNamespace):
-                return self._dump_error_namespace(namespace, variant, log_errors)
+                self._dump_error_namespace(namespace, variant, log_errors)
             elif isinstance(namespace, MaxDepthNamespace):
-                return self._dump_max_depth_namespace(namespace, variant, log_errors)
+                self._dump_max_depth_namespace(namespace, variant, log_errors)
             elif isinstance(namespace, FormattedNamespace):
-                return self._dump_formatted_namespace(namespace, variant, log_errors)
+                self._dump_formatted_namespace(namespace, variant, log_errors)
             elif isinstance(namespace, UnknownNamespace):
-                return self._dump_unknown_namespace(namespace, variant, log_errors)
+                self._dump_unknown_namespace(namespace, variant, log_errors)
             elif isinstance(namespace, CodeObjectNamespace):
-                return self.dump_code_namespace(namespace, variant, log_errors)
+                self.dump_code_namespace(namespace, variant, log_errors)
             elif isinstance(namespace, DynamicObjectNamespace):
-                return self.dump_dynamic_namespace(namespace, variant, log_errors)
+                self.dump_dynamic_namespace(namespace, variant, log_errors)
             else:
                 raise NotImplementedError("Does not support serializing this type!", type(namespace))
         except Exception as e:
             message = "Failed to serialize namespace"
 
-            from .error import Error
+            from .error import Error  # lgtm[py/cyclic-import]
             variant.Clear()
             variant.variant_type = variant.VARIANT_ERROR
 
@@ -94,6 +94,7 @@ class NamespaceSerializer(object):
         self.dump(namespace, variant, log_errors)
         return variant
 
+    # TODO - remove this entire flow (used only for testing, barely even that)
     def loads(self, message):
         return self._load_variant(message)
 
@@ -394,7 +395,7 @@ class NamespaceSerializer(object):
 
                     self._dump_python_object(field[1], attribute.value, current_depth - 1, config,
                                                  log_errors)
-                except:
+                except Exception:  # for now we just ignore errors when dumping protobuf
                     pass
 
     def _dump_exception(self, exc, variant, current_depth, config, log_errors):
@@ -532,7 +533,7 @@ class NamespaceSerializer(object):
             message = "Failed to serialize namespace"
             logger.exception(message)
 
-            from .error import Error
+            from .error import Error  # lgtm[py/cyclic-import]
             error = Error(exc=e, message=message)
 
             # This is a duplication of Error as we can't use it here safely
