@@ -7,7 +7,6 @@ from rook.exceptions import RookKeyNotFound, RookAttributeNotFound, RookInvalidM
 
 
 class PythonObjectNamespace(Namespace):
-
     try:
         BINARY_TYPES = (buffer, bytearray)
     except NameError:
@@ -40,11 +39,9 @@ class PythonObjectNamespace(Namespace):
             self.max_string = max_string or self.DEFAULT_MAX_STRING
 
         def __eq__(self, other):
-            try :
-                return self.max_depth == other.max_depth and self.max_width == other.max_width and \
-                       self.max_collection_dump == other.max_collection_dump and self.max_string == other.max_string
-            except:
-                return False
+            return type(self) == type(other) and self.max_depth == other.max_depth and \
+                   self.max_width == other.max_width and self.max_collection_dump == other.max_collection_dump and \
+                   self.max_string == other.max_string
 
         @classmethod
         def strict_limits(cls, obj):
