@@ -173,7 +173,7 @@ class ImportService(object):
                 from gevent.monkey import is_module_patched
                 if is_module_patched("threading"):
                     time.sleep(ImportServiceConfig.SYS_MODULES_QUERY_INTERVAL)
-            except:
+            except Exception:  # Nothing we can do here but join as usual
                 pass
 
             self._thread.join()
@@ -264,7 +264,7 @@ class ImportService(object):
             try:
                 with CountingImportLock():
                     self.evaluate_module_list()
-            except:
+            except:  # lgtm[py/catch-base-exception]
                 if logger:
                     logger.exception("Error while evaluating module list")
 
@@ -300,7 +300,7 @@ class ImportService(object):
             # Update the "old" list
             self._modules = module_names
 
-        except:
+        except Exception:
             logger.exception("Exception in ImportService")
 
     def _notify_of_new_module(self, module_name, module_object, module_filename):
@@ -313,7 +313,7 @@ class ImportService(object):
                                                         self.external_paths):
                     try:
                         notification.callback(module)
-                    except:
+                    except:  # lgtm[py/catch-base-exception]
                         logger.exception("Error on module load callback")
                 elif os.path.basename(notification.module_filename) == os.path.basename(module_filename):
                     file_content = self.file_utils.get_safe_file_contents(module)
@@ -336,7 +336,7 @@ class ImportService(object):
                 if not path:
                     if module.__file__.endswith('.pyc'):
                         path = module.__file__.replace('.pyc', '.py')
-            except:
+            except Exception:
                 return None
 
             if path:
