@@ -3,9 +3,7 @@
 import fnmatch
 import sys
 import os
-import types
 import threading
-import inspect
 from six import print_
 from collections import defaultdict
 
@@ -65,7 +63,7 @@ class Bdb:
                 return
 
         except ImportError:
-            pass
+            pass # No need to worry about gevent, continue as usual
 
         if not self.trace_through and self.sys_gettrace() == self.trace_dispatch:
             self.sys_settrace(None)
@@ -166,9 +164,9 @@ class Bdb:
             return None
 
         if event == 'line':
-            # This if is a 'flattened' version of dispatch_line to optimize performance
+            # This if is an inlined version of dispatch_line to optimize performance
             # Original version:
-            # if self.break_here(frame):
+            # if self.break_here(frame):  lgtm[py/commented-out-code]
             #    if self.user_line:
             #        self.user_line(frame)
             # return self.trace_dispatch
@@ -213,9 +211,9 @@ class Bdb:
             return self.trace_dispatch
 
         if event == 'call':
-            # This if is a 'flattened' version of dispatch_call to optimize performance
+            # This if is an inlined version of dispatch_call to optimize performance
             # Original version:
-            # if self.break_anywhere(frame):
+            # if self.break_anywhere(frame):  lgtm[py/commented-out-code]
             #     return self.trace_dispatch
             # else:
             #    return self.trace_dispatch_default
@@ -290,11 +288,11 @@ class Bdb:
 
         if event == 'c_call':
             if self.trace_through:
-                tracefunc = self._get_thread_trace_func(frame)
+                tracefunc = self._get_thread_trace_func()
                 if tracefunc:
                     tracefunc_ret = tracefunc(frame, event, arg)
                     if tracefunc_ret:
-                        retval = self.trace_dispatch
+                        self.trace_dispatch
                     self._set_frame_trace_func(tracefunc_ret, frame)
             return None
 
@@ -302,20 +300,20 @@ class Bdb:
             if self.trace_through:
                 tracefunc = self._get_frame_trace_func(frame)
                 if tracefunc:
-                    tracefunc = tracefunc(frame, event, arg)
+                    tracefunc(frame, event, arg)
             return None
         if event == 'c_return':
             if self.trace_through:
                 tracefunc = self._get_frame_trace_func(frame)
                 if tracefunc:
-                    tracefunc = tracefunc(frame, event, arg)
+                    tracefunc(frame, event, arg)
             return None
 
         print_('bdb.Bdb.dispatch: unknown debugging event:', repr(event))
         if self.trace_through:
-            tracefunc = self._get_thread_trace_func(frame)
+            tracefunc = self._get_thread_trace_func()
             if tracefunc:
-                tracefunc = tracefunc(frame, event, arg)
+                tracefunc(frame, event, arg)
         return self.trace_dispatch
 
     def dispatch_line(self, frame):
@@ -403,13 +401,6 @@ class Bdb:
                   funcname=None):
         filename = self.canonic(filename)
 
-        # TODO - reenable this test in the future
-        #import linecache # Import as late as possible
-        #line = linecache.getline(filename, lineno)
-        #if not line:
-        #    return 'Line %s:%d does not exist' % (filename,
-        #                           lineno)
-
         if not filename in self.breaks:
             self.breaks[filename] = []
         list = self.breaks[filename]
@@ -417,7 +408,7 @@ class Bdb:
             list.append(lineno)
         self.aug_ids[aug_id] = (filename, lineno)
         self.positions[(filename, lineno)].append(aug_id)
-        bp = Breakpoint(filename, lineno, temporary, cond, funcname)
+        Breakpoint(filename, lineno, temporary, cond, funcname)
 
         self.update_activity()
 
@@ -431,10 +422,11 @@ class Bdb:
         filename, lineno = self.aug_ids[aug_id]
         filename = self.canonic(filename)
         if not filename in self.breaks:
-            return 'There are no breakpoints in %s' % filename
+            return
+
         if lineno not in self.breaks[filename]:
-            return 'There is no breakpoint at %s:%d' % (filename,
-                                    lineno)
+            return
+
         # If there's only one bp in the list for that file,line
         # pair, then remove the breaks entry
         for bp in Breakpoint.bplist[filename, lineno][:]:
@@ -447,7 +439,8 @@ class Bdb:
 
     def clear_all_breaks(self):
         if not self.breaks:
-            return 'There are no breakpoints'
+            return
+
         for bp in Breakpoint.bpbynumber:
             if bp:
                 bp.deleteMe()
