@@ -17,9 +17,10 @@ from rook.com_ws.output_ws import Output
 
 from .augs.augs_manager import AugsManager
 from .trigger_services import TriggerServices
+from .services.monitor.monitor_service import MonitorService
 
 from rook.exceptions import RookInterfaceException, RookVersionNotSupported
-from rook.com_ws.agent_com_ws import AgentCom
+from rook.com_ws.agent_com_ws import AgentCom, thread_connection_type, SINGLE_THREAD_AGENT_COM
 from rook.com_ws.command_handler import CommandHandler
 
 try:
@@ -42,6 +43,7 @@ class _Singleton(object):
         self._id = None
         self._services_started = False
 
+        self._monitor_service = None
         self._trigger_services = TriggerServices()
         self._command_handler = None
         self._aug_manager = None
@@ -49,7 +51,7 @@ class _Singleton(object):
 
         self._agent_com = None
 
-    def _start_trigger_services(self):
+    def _start_trigger_services(self, _enable_monitor=True):
         """Start trigger services.
 
         Calling this method multiple times will have no effect.
@@ -61,6 +63,10 @@ class _Singleton(object):
         self._init_id()
         self._output = Output(self._id)
 
+        if _enable_monitor:
+            self._monitor_service = MonitorService.get_instance()
+            self._monitor_service.start()
+
         self._trigger_services.start()
         self._aug_manager = AugsManager(self._trigger_services, self._output)
         self._services_started = True
@@ -72,6 +78,9 @@ class _Singleton(object):
         if not self._services_started:
             return
 
+        if self._monitor_service:
+            self._monitor_service.stop()
+
         self._aug_manager = None
         self._trigger_services.close()
 
@@ -80,7 +89,8 @@ class _Singleton(object):
     def get_trigger_services(self):
         return self._trigger_services
 
-    def connect(self, token, host, port, proxy, tags=None, labels=None, async_start=False, fork=False, debug=False):
+    def connect(self, token, host, port, proxy, tags=None, labels=None, async_start=False, fork=False, debug=False,
+                _enable_monitor=True):
         """Connect to the Agent."""
         if self._agent_com:
             raise RookInterfaceException("Multiple connection attempts not supported!")
@@ -129,10 +139,16 @@ class _Singleton(object):
         self._agent_com.restart()
 
     def pre_fork(self):
-        # AgentCom is fork safe (the child will lose the thread) so there's nothing we need to do with it
+        if self._agent_com is not None and thread_connection_type is SINGLE_THREAD_AGENT_COM:
+            # to avoid new child to write father's fd in single-threaded communication
+            self._agent_com.stop()
+
         self._trigger_services.pre_fork()
 
     def post_fork_recover(self):
+        if self._agent_com is not None and thread_connection_type is SINGLE_THREAD_AGENT_COM:
+            self._agent_com.start()
+
         self._trigger_services.post_fork()
 
     def post_fork_clean(self):
@@ -179,7 +195,7 @@ def exit_handler():
         if singleton_obj._agent_com:
             singleton_obj.flush()
             singleton_obj._agent_com.stop()
-    except:
+    except:  # lgtm[py/catch-base-exception]
         logger.exception("Flush and close failed")
     logger.info("Exit handler finished")
 
